\connect "template1"

drop USER tddbadmin;
CREATE USER tddbadmin WITH PASSWORD 'tddbcm' CREATEDB CREATEUSER;

\set ON_ERROR_STOP
--
-- Database creation
--
CREATE DATABASE cmpc_tddb WITH TEMPLATE = template0 OWNER = postgres ENCODING = 'UNICODE';

ALTER USER postgres WITH CREATEDB CREATEUSER;

\connect cmpc_tddb

--
-- PostgreSQL database dump
--

SET client_encoding = 'UNICODE';
SET check_function_bodies = false;
SET client_min_messages = warning;

COMMENT ON SCHEMA public IS 'Standard public schema';


SET search_path = public, pg_catalog;

SET default_tablespace = '';

SET default_with_oids = true;

--
-- Name: db_log; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE db_log (
    log_id bigserial NOT NULL,
    operation_info character varying(255) DEFAULT ''::character varying NOT NULL,
    operation_type character varying(32) DEFAULT ''::character varying NOT NULL,
    operator_name character varying(32) DEFAULT ''::character varying NOT NULL,
    operation_result character varying(32) DEFAULT ''::character varying NOT NULL,
    operation_time timestamp without time zone DEFAULT '1999-01-01 01:00:00'::timestamp without time zone NOT NULL
);


ALTER TABLE public.db_log OWNER TO postgres;
--
-- Name: queue_info; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE queue_info (
    device_hw_id character varying(128) DEFAULT ''::character varying NOT NULL,
    queue_req_ss timestamp without time zone,
    queue_req_obc timestamp without time zone,
    queue_req_cbc timestamp without time zone,
    queue_req_isp timestamp without time zone,
    queue_req_pk timestamp without time zone,
    queue_req_proc character(1) DEFAULT ''::bpchar,
    queue_resend_times character(2) DEFAULT ''::bpchar,
    queue_req_mg timestamp without time zone
);
ALTER TABLE ONLY queue_info
    ADD CONSTRAINT queue_info_pkey PRIMARY KEY (device_hw_id);

ALTER TABLE public.db_log OWNER TO postgres;

--
-- Name: db_log_log_id_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval(pg_catalog.pg_get_serial_sequence('db_log', 'log_id'), 8, true);


--
-- Name: device_account_info; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE device_account_info (
    device_id bigserial NOT NULL,
    owner_id character varying(128) DEFAULT ''::character varying NOT NULL,
    owner_pwd character varying(32) DEFAULT ''::character varying NOT NULL,
    owner_name character varying(128) DEFAULT ''::character varying NOT NULL,
    owner_team character varying(32) DEFAULT ''::character varying NOT NULL,
    owner_birthday character varying(16) DEFAULT ''::character varying NOT NULL,
    owner_type character varying(10) DEFAULT ''::character varying,
    device_hw_id character varying(128) DEFAULT ''::character varying NOT NULL,
    boot_tick character varying(10) DEFAULT ''::character varying,
    shared_key text,
    old_shared_key text,
    boot_times character varying(100) DEFAULT '20'::character varying,
    expiration_date timestamp without time zone DEFAULT '2099-12-31 23:59:59'::timestamp without time zone,
    stolen_flag character(1),
    stolen_time timestamp without time zone DEFAULT '1999-01-01 01:00:00'::timestamp without time zone,
    unboot_flag character(1) DEFAULT ''::bpchar,
    last_getcert_time timestamp without time zone DEFAULT '1999-01-01 01:00:00'::timestamp without time zone,
    special_flag character(1) DEFAULT ''::bpchar,
    sharedkey_flag character(1) DEFAULT ''::bpchar,
    reg_time timestamp without time zone DEFAULT '1999-01-01 01:00:00'::timestamp without time zone,
    device_comment text,
    temp_shared_key text,
    public_key_flag character(1) DEFAULT '0'::bpchar,
    activation_flag character(1) DEFAULT '1'::bpchar,
    temp_onetime_ED timestamp without time zone DEFAULT '1999-01-01 01:00:00'::timestamp without time zone,
    temp_onetime_BC character varying(100) DEFAULT ''::character varying,
    bak_onetime_ED timestamp without time zone DEFAULT '1999-01-01 01:00:00'::timestamp without time zone,
    bak_special_flag character(1) DEFAULT ''::bpchar,
    migrate_status character(1) DEFAULT '0'::bpchar,
    migrate_flag character(1) DEFAULT '0'::bpchar,
    migrate_school_name character varying(128) DEFAULT ''::character varying,
    applied_date timestamp without time zone DEFAULT '1999-01-01 01:00:00'::timestamp without time zone,
    school_migrate INT DEFAULT 0::INT,
    gen_mgkey_date timestamp without time zone DEFAULT '1999-01-01 01:00:00'::timestamp without time zone,
    down_mgkey_date timestamp without time zone DEFAULT '1999-01-01 01:00:00'::timestamp without time zone,
    root_pk_hash character varying(255),
    boot_count character varying(100) DEFAULT '100'::character varying,
    last_device_connect_time timestamp without time zone DEFAULT '1999-01-01 01:00:00'::timestamp without time zone,
    group_id integer
);

create index device_hw_id on device_account_info (device_hw_id);
create index special_flag on device_account_info (special_flag);

--
-- Name: device_common_info; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE device_common_info (
    common_boot_times character varying(100) DEFAULT ''::character varying,
    common_expiration_days character varying(100) DEFAULT ''::character varying NOT NULL,
    temp_boot_times character varying(100) DEFAULT ''::character varying,
    temp_expiration_days character varying(100) DEFAULT ''::character varying NOT NULL,
    public_key text,
    send_public_key text
);

--
-- Name: operator_info; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE operator_info (
    operator_name character varying(32) DEFAULT ''::character varying NOT NULL,
    operator_pwd character varying(128),
    operate_type character varying(10) DEFAULT ''::character varying NOT NULL,
    reg_date timestamp without time zone DEFAULT '1999-01-01 01:00:00'::timestamp without time zone NOT NULL,
    operator_comment text
);

--
-- Name: tracking_info; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE tracking_info (
    tracking_id bigserial NOT NULL,
    owner_id character varying(128) DEFAULT ''::character varying NOT NULL,
    device_id character varying(128) DEFAULT ''::character varying NOT NULL,
    network_ip character varying(255) DEFAULT ''::character varying NOT NULL,
    gateway_ip character varying(255) DEFAULT ''::character varying NOT NULL,
    network_proxy character varying(255) DEFAULT ''::character varying,
    dns_ip character varying(255) DEFAULT ''::character varying,
    wins_ip character varying(255) DEFAULT ''::character varying,
    owner_local_time timestamp without time zone DEFAULT '1999-01-01 01:00:00'::timestamp without time zone NOT NULL,
    stolen_flag character(1) DEFAULT ''::bpchar,
    stolen_time timestamp without time zone DEFAULT '1999-01-01 01:00:00'::timestamp without time zone,
    owner_team character varying(32) DEFAULT ''::character varying,
    reg_time timestamp without time zone DEFAULT '1999-01-01 01:00:00'::timestamp without time zone,
    tracking_comment text,
    ssid_ap character varying(128) DEFAULT ''::character varying,
    os_version character varying(128) DEFAULT ''::character varying,
    computer_name text
);

--
-- Name: message; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--
CREATE TABLE message (
	record_id bigint DEFAULT 0::bigint NOT NULL,
	message_type INT DEFAULT 0::INT NOT NULL,
	message_date character varying(128) DEFAULT ''::character varying,
	message_info text,
	message_is_readed boolean DEFAULT false::boolean NOT NULL
);
--
-- Name: update_flag; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--
CREATE TABLE update_flag
(
  	is_update character(1) DEFAULT '1'::bpchar
);
insert into update_flag(is_update) values('1');

CREATE TABLE tds_status
(
  	status character(1) DEFAULT '0'::bpchar NOT NULL
);
insert into tds_status(status) values('0');

--
-- Name: version_info; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--
CREATE TABLE version_info (
	version character varying(128) DEFAULT ''::character varying NOT NULL
);
ALTER TABLE ONLY version_info
    ADD CONSTRAINT version_info_pkey PRIMARY KEY (version);
insert into version_info  (version) values ('3.1.0.3.3.1');

COPY device_common_info (common_boot_times, common_expiration_days) FROM stdin;
20	30
\.

--
-- Data for Name: operator_info; Type: TABLE DATA; Schema: public; Owner: postgres
--
insert into operator_info  (operator_name,operator_pwd,operate_type,reg_date,operator_comment) values ('admin','40bd001563085fc35165329ea1ff5c5ecbdbbeef','admin',now(),'super admin');

--
-- Name: db_log_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY db_log
    ADD CONSTRAINT db_log_pkey PRIMARY KEY (log_id);

--
-- Name: device_account_info_device_hw_id_key; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY device_account_info
    ADD CONSTRAINT device_account_info_device_hw_id_key UNIQUE (device_hw_id);

--
-- Name: device_account_info_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY device_account_info
    ADD CONSTRAINT device_account_info_pkey PRIMARY KEY (device_id);


--
-- Name: operator_info_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY operator_info
    ADD CONSTRAINT operator_info_pkey PRIMARY KEY (operator_name);

--
-- Name: tracking_info_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY tracking_info
    ADD CONSTRAINT tracking_info_pkey PRIMARY KEY (tracking_id);

--
-- Name: message_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--
ALTER TABLE ONLY message
    ADD CONSTRAINT message_pkey PRIMARY KEY (record_id, message_date);


--
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
REVOKE ALL ON SCHEMA public FROM tddbadmin;
GRANT ALL ON SCHEMA public TO tddbadmin;
GRANT ALL ON SCHEMA public TO PUBLIC;


--
-- PostgreSQL database dump complete
--

\connect template1

--
-- PostgreSQL database cluster dump complete
--

